[![PyPI version](https://badge.fury.io/py/dsp-tools.svg)](https://badge.fury.io/py/dsp-tools)

# General Formatting

## [EditorConfig](https://EditorConfig.org)

Language-independent, cross-editor settings for indentation, line endings, etc.

## [MarkdownLint](https://github.com/igorshubovych/markdownlint-cli)

A CLI for David Anson's MarkdownLint, a static analysis tool with a library of rules.
The flexibility of the Markdown syntax is both a benefit and a drawback. 
Many styles are possible, so formatting can be inconsistent. 
Some constructs don't work well in all parsers and should be avoided.
